@@ -5,8 +5,8 @@ if __name__ == "__main__":
 
 import unittest
 
-from hamcrest.core.base_matcher import *
-from hamcrest_unit_test.matcher_test import *
+from hamcrest.core.base_matcher import BaseMatcher
+from hamcrest_unit_test.matcher_test import assert_match_description, assert_mismatch_description
 
 __author__ = "Jon Reid"
 __copyright__ = "Copyright 2011 hamcrest.org"
@@ -37,6 +37,19 @@ class BaseMatcherTest(unittest.TestCase):
     def testMatchDescriptionShouldDescribeItem(self):
         assert_match_description("was <99>", PassingBaseMatcher(), 99)
 
+    def testMatcherReprShouldDescribeMatcher(self):
+        assert repr(FailingBaseMatcher()) == "<FailingBaseMatcher(SOME DESCRIPTION)>"
+
+    def testMatcherReprShouldTruncateLongDescription(self):
+        class LongDescriptionMatcher(BaseMatcher):
+            def describe_to(self, description):
+                description.append_text("1234 " * 13)
+
+        assert (
+            repr(LongDescriptionMatcher())
+            == "<LongDescriptionMatcher(1234 1234 1234 1234 1234 1234 1234 1234 1234 1234 1234...)>"
+        )
+
 
 if __name__ == "__main__":
     unittest.main()
