@@ -6,8 +6,7 @@ __license__ = "BSD, see License.txt"
 
 
 class NeverMatch(BaseMatcher):
-
-    mismatch_description = 'NEVERMATCH'
+    mismatch_description = "NEVERMATCH"
 
     def matches(self, item, mismatch_description=None):
         if mismatch_description:
